@@ -4,15 +4,16 @@ using ConcreteStructs: @concrete
 using DataStructures: DataStructures, BinaryMaxHeap, BinaryMinHeap
 using DiffEqBase: DiffEqBase, get_tstops, get_tstops_array, get_tstops_max
 using DifferentiationInterface: DifferentiationInterface, Constant
-using LinearAlgebra: LinearAlgebra, adjoint, axpy!, copyto!, mul!, ldiv!
+using LinearAlgebra: LinearAlgebra, adjoint, axpy!, copyto!, diagind, mul!, ldiv!
 using Markdown: @doc_str
+using PrecompileTools: PrecompileTools
 using RecipesBase: @recipe
 using RecursiveArrayTools: RecursiveArrayTools, DiffEqArray, copyat_or_push!
 using SciMLBase: SciMLBase, CallbackSet, DiscreteCallback, NonlinearFunction,
-                 NonlinearLeastSquaresProblem, NonlinearProblem, RODEProblem,
-                 ReturnCode, SDEProblem, add_tstop!, check_error, get_du,
-                 get_proposed_dt, get_tmp_cache, init, reinit!,
-                 set_proposed_dt!, solve!, terminate!, u_modified!
+    NonlinearLeastSquaresProblem, NonlinearProblem, RODEProblem,
+    ReturnCode, SDEProblem, add_tstop!, check_error, get_du,
+    get_proposed_dt, get_tmp_cache, init, reinit!,
+    set_proposed_dt!, solve!, terminate!, u_modified!
 using StaticArraysCore: StaticArraysCore
 
 const DI = DifferentiationInterface
@@ -34,5 +35,6 @@ include("preset_time.jl")
 include("probints.jl")
 include("integrating_GK_affect.jl")
 include("integrating_GK_sum.jl")
+include("precompilation.jl")
 
 end # module
