@@ -8,7 +8,7 @@ function recursive_copyto! end
 recursive_copyto!(y::AbstractArray, x::AbstractArray) = internal_copyto!(y, x)
 
 function internal_copyto!(y, x)
-    hasmethod(copyto!, Tuple{typeof(y), typeof(x)}) ? copyto!(y, x) : nothing
+    return hasmethod(copyto!, Tuple{typeof(y), typeof(x)}) ? copyto!(y, x) : nothing
 end
 
 """
@@ -31,6 +31,8 @@ internal_neg!(x) = nothing
 function recursive_zero! end
 
 recursive_zero!(x::AbstractArray) = internal_zero!(x)
+recursive_zero!(x::Number) = zero(x)
+recursive_zero!(::Nothing) = nothing
 
 internal_zero!(x::AbstractArray) = fill!(x, false)
 internal_zero!(x) = nothing
@@ -79,6 +81,8 @@ allocate_vjp_internal(λ::AbstractArray, x) = similar(λ, size(x))
 function allocate_zeros end
 
 allocate_zeros(x::AbstractArray) = internal_allocate_zeros(x)
+allocate_zeros(x::Number) = zero(x)
+allocate_zeros(::Nothing) = nothing
 
 internal_allocate_zeros(x) = hasmethod(zero, Tuple{typeof(x)}) ? zero(x) : nothing
 
@@ -90,6 +94,8 @@ recursive_copy(y)
 function recursive_copy end
 
 recursive_copy(x::AbstractArray) = internal_copy(x)
+recursive_copy(x::Number) = x
+recursive_copy(::Nothing) = nothing
 
 internal_copy(x) = hasmethod(copy, Tuple{typeof(x)}) ? copy(x) : nothing
 
@@ -107,6 +113,8 @@ internal_adjoint(x) = hasmethod(adjoint, Tuple{typeof(x)}) ? adjoint(x) : nothin
 function recursive_scalar_mul! end
 
 recursive_scalar_mul!(x::AbstractArray, α) = internal_scalar_mul!(x, α)
+recursive_scalar_mul!(x::Number, α) = x * α
+recursive_scalar_mul!(::Nothing, α) = nothing
 
 internal_scalar_mul!(x::Number, α) = x * α
 internal_scalar_mul!(x::AbstractArray, α) = x .*= α
@@ -115,6 +123,9 @@ internal_scalar_mul!(x, α) = nothing
 function recursive_axpy! end
 
 recursive_axpy!(α, x::AbstractArray, y::AbstractArray) = internal_axpy!(α, x, y)
+recursive_axpy!(α, x::Number, y::Number) = y + α * x
+# For out-of-place integrands with nothing as accumulator, start accumulation
+recursive_axpy!(α, x, ::Nothing) = α * x
 
 internal_axpy!(α, x::AbstractArray, y::AbstractArray) = axpy!(α, x, y)
 internal_axpy!(α, x, y) = nothing
