@@ -16,9 +16,13 @@ end
 function rober(u, p::TrackedArray, t)
     y₁, y₂, y₃ = u
     k₁, k₂, k₃ = p
-    return Tracker.collect([-k₁ * y₁ + k₃ * y₂ * y₃,
-        k₁ * y₁ - k₂ * y₂^2 - k₃ * y₂ * y₃,
-        k₂ * y₂^2])
+    return Tracker.collect(
+        [
+            -k₁ * y₁ + k₃ * y₂ * y₃,
+            k₁ * y₁ - k₂ * y₂^2 - k₃ * y₂ * y₃,
+            k₂ * y₂^2,
+        ]
+    )
 end
 
 p = TrackedArray([1.9f0, 1.0f0, 3.0f0])
@@ -28,12 +32,19 @@ prob = ODEProblem{false}(rober, u0, tspan, p)
 saved_values = SavedValues(eltype(tspan), eltype(p))
 cb = SavingCallback((u, t, integrator) -> integrator.EEst * integrator.dt, saved_values)
 
-@test !all(iszero.(Tracker.gradient(
-    p -> begin
-        solve(remake(prob, u0 = u0, p = p, tspan = tspan),
-            Tsit5(),
-            sensealg = SensitivityADPassThrough(),
-            callback = cb)
-        return sum(saved_values.saveval)
-    end,
-    p)[1]))
\ No newline at end of file
+@test !all(
+    iszero.(
+        Tracker.gradient(
+            p -> begin
+                solve(
+                    remake(prob, u0 = u0, p = p, tspan = tspan),
+                    Tsit5(),
+                    sensealg = SensitivityADPassThrough(),
+                    callback = cb
+                )
+                return sum(saved_values.saveval)
+            end,
+            p
+        )[1]
+    )
+)
